@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 __title__ = 'camote'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __author__ = 'Marconi Moreto'
 
 
 from . import utils
-from .queues import CamoteQueue
+from .queues import Job, CamoteQueue
